import { SchemeSetting } from './color_functions/color_module';
import { ColorShifting } from './models';

export type ColorSet = {
  root: string;
  hover: string;
  active: string;
  focus: string;
  disabled: string;
  onRoot: string;
  onHover: string;
  onActive: string;
  onFocus: string;
  onDisabled: string;
};

export type Baseline = {
  primary: ColorSet;
  secondary: ColorSet | null;
  tertiary: ColorSet | null;
  accent: ColorSet | null;
  neutral: ColorSet;
  danger: ColorSet;
  success: ColorSet;
  warning: ColorSet;
  info: ColorSet;
  outline: ColorSet;
  foreground: ColorSet;
  background: ColorSet;
};

export type QScheme = {
  light: Baseline | null;
  dark: Baseline | null;
};

export type QSchemeSetting = {
  hover: ColorShifting;
  acitve: ColorShifting;
  focus: ColorShifting;
  disabled: ColorShifting;
  dark_convert: ColorShifting;
  expand_method: string;
  wacg_follows: string;
};

export type QSchemeSource = {
  primary: string | null;
  secondary: string | null;
  tertiary: string | null;
  accent: string | null;
  danger: string | null;
  success: string | null;
  warning: string | null;
  info: string | null;
  foreground: string | null;
  background: strin | nullg;
  setting: SchemeSetting | null;
};

export type QSchemeStorage = {
  source?: QSchemeSource;
  scheme?: QScheme;
  cssVariables?: string;
  scssVariables?: string;
  jsVariables?: string;
};
